# **dpyp (Data-Pipe)**
*A pandas convenience wrapper for small-scale data pipelines*

<p align = "center">
  <img src = "logo/dpyp_logo.png" alt = "image" width = "300" height = "300">
</p>

## Use
- dpyp allows users to gather target files from directories into data dictionaries.
- Users can then apply cleaning and transformation functions iteratively to dictionaries, making batch processing quick to write and highly readable.